@@ -18,7 +18,9 @@ from .teletypes import (
     BotCommand,
     WebhookInfo,
     InputMedia,
-    Poll)
+    Poll,
+    BotCommandScope
+)
 
 from .teletypes.inline_query_result import InlineQueryResult
 
@@ -110,7 +112,8 @@ def send_message(token: str,
                  disable_web_page_preview: Optional[bool] = None,
                  disable_notification: Optional[bool] = None,
                  reply_to_message_id: Optional[int] = None,
-                 reply_markup: Optional[ReplyMarkup] = None) -> Message:
+                 reply_markup: Optional[ReplyMarkup] = None,
+                 protect_content: Optional[bool] = None) -> Message:
     """Use this method to send text messages.
 
     On success, the sent Message is returned.
@@ -123,7 +126,8 @@ def send_message(token: str,
             'disable_notification': disable_notification,
             'reply_to_message_id': reply_to_message_id,
             'reply_markup': (reply_markup.unfold()
-                             if reply_markup is not None else None)
+                             if reply_markup is not None else None),
+            'protect_content': protect_content
         }
     return request(
         token,
@@ -137,7 +141,9 @@ def forward_message(token: str,
                     chat_id: Union[int, str],
                     from_chat_id: Union[int, str],
                     message_id: int,
-                    disable_notification: Optional[bool] = None) -> Message:
+                    disable_notification: Optional[bool] = None,
+                    protect_content: Optional[bool] = None
+                    ) -> Message:
     """Use this method to forward messages of any kind.
 
     On success, the sent Message is returned.
@@ -146,7 +152,8 @@ def forward_message(token: str,
         'chat_id': chat_id,
         'from_chat_id': from_chat_id,
         'message_id': message_id,
-        'disable_notification': disable_notification
+        'disable_notification': disable_notification,
+        'protect_content': protect_content
     }
 
     return request(
@@ -164,7 +171,8 @@ def send_photo(token: str,
                parse_mode: Optional[str] = None,
                disable_notification: Optional[bool] = None,
                reply_to_message_id: Optional[int] = None,
-               reply_markup: Optional[ReplyMarkup] = None
+               reply_markup: Optional[ReplyMarkup] = None,
+               protect_content: Optional[bool] = None
                ) -> Message:
     """Use this method to send photos.
 
@@ -177,7 +185,8 @@ def send_photo(token: str,
             'disable_notification': disable_notification,
             'reply_to_message_id': reply_to_message_id,
             'reply_markup': (reply_markup.unfold()
-                             if reply_markup is not None else None)
+                             if reply_markup is not None else None),
+            'protect_content': protect_content
         }
     if not isinstance(photo, str):
         return request(token,
@@ -206,7 +215,8 @@ def send_audio(token: str,
                thumb: Optional[Union[str, IO]] = None,
                disable_notification: Optional[bool] = None,
                reply_to_message_id: Optional[int] = None,
-               reply_markup: Optional[ReplyMarkup] = None
+               reply_markup: Optional[ReplyMarkup] = None,
+               protect_content: Optional[bool] = None
                ) -> Message:
     """Use this method to send audio files.
 
@@ -222,7 +232,8 @@ def send_audio(token: str,
             'title': title,
             'performer': performer,
             'reply_markup': (reply_markup.unfold()
-                             if reply_markup is not None else None)
+                             if reply_markup is not None else None),
+            'protect_content': protect_content
         }
     files = dict()
     if isinstance(audio, str):
@@ -251,7 +262,8 @@ def send_document(token: str,
                   parse_mode: Optional[str] = None,
                   disable_notification: Optional[bool] = None,
                   reply_to_message_id: Optional[int] = None,
-                  reply_markup: Optional[ReplyMarkup] = None
+                  reply_markup: Optional[ReplyMarkup] = None,
+                  protect_content: Optional[bool] = None
                   ) -> Message:
     """Use this method to send general files.
 
@@ -264,7 +276,8 @@ def send_document(token: str,
             'disable_notification': disable_notification,
             'reply_to_message_id': reply_to_message_id,
             'reply_markup': (reply_markup.unfold()
-                             if reply_markup is not None else None)
+                             if reply_markup is not None else None),
+            'protect_content': protect_content
         }
 
     files = dict()
@@ -298,7 +311,8 @@ def send_video(token: str,
                supports_streaming: Optional[bool] = None,
                disable_notification: Optional[bool] = None,
                reply_to_message_id: Optional[int] = None,
-               reply_markup: Optional[ReplyMarkup] = None
+               reply_markup: Optional[ReplyMarkup] = None,
+               protect_content: Optional[bool] = None
                ) -> Message:
     """Use this method to send video files.
 
@@ -316,7 +330,8 @@ def send_video(token: str,
             'disable_notification': disable_notification,
             'reply_to_message_id': reply_to_message_id,
             'reply_markup': (reply_markup.unfold()
-                             if reply_markup is not None else None)
+                             if reply_markup is not None else None),
+            'protect_content': protect_content
         }
 
     files = dict()
@@ -349,7 +364,8 @@ def send_animation(token: str,
                    parse_mode: Optional[str] = None,
                    disable_notification: Optional[bool] = None,
                    reply_to_message_id: Optional[int] = None,
-                   reply_markup: Optional[ReplyMarkup] = None
+                   reply_markup: Optional[ReplyMarkup] = None,
+                   protect_content: Optional[bool] = None
                    ) -> Message:
     """Use this method to send animation files (GIF or video without sound).
 
@@ -364,9 +380,10 @@ def send_animation(token: str,
         'caption': caption,
         'parse_mode': parse_mode,
         'disable_notification': disable_notification,
-        'reply_to_message_id': disable_notification,
+        'reply_to_message_id': reply_to_message_id,
         'reply_markup': (reply_markup.unfold()
-                         if reply_markup is not None else None)
+                         if reply_markup is not None else None),
+        'protect_content': protect_content
     }
 
     files = dict()
@@ -396,7 +413,8 @@ def send_voice(token: str,
                duration: Optional[int] = None,
                disable_notification: Optional[bool] = None,
                reply_to_message_id: Optional[int] = None,
-               reply_markup: Optional[ReplyMarkup] = None
+               reply_markup: Optional[ReplyMarkup] = None,
+               protect_content: Optional[bool] = None
                ) -> Message:
     """Use this method to send audio files to display the file as a voice message.
 
@@ -409,9 +427,10 @@ def send_voice(token: str,
         'caption': caption,
         'parse_mode': parse_mode,
         'disable_notification': disable_notification,
-        'reply_to_message_id': disable_notification,
+        'reply_to_message_id': reply_to_message_id,
         'reply_markup': (reply_markup.unfold()
-                         if reply_markup is not None else None)
+                         if reply_markup is not None else None),
+        'protect_content': protect_content
     }
 
     files = dict()
@@ -437,7 +456,8 @@ def send_video_note(token: str,
                     thumb: Optional[Union[str, IO]] = None,
                     disable_notification: Optional[bool] = None,
                     reply_to_message_id: Optional[int] = None,
-                    reply_markup: Optional[ReplyMarkup] = None
+                    reply_markup: Optional[ReplyMarkup] = None,
+                    protect_content: Optional[bool] = None
                     ) -> Message:
     """Use this method to send rounded square mp4 videos of up to 1 minute long.
 
@@ -449,7 +469,8 @@ def send_video_note(token: str,
             'disable_notification': disable_notification,
             'reply_to_message_id': reply_to_message_id,
             'reply_markup': (reply_markup.unfold()
-                             if reply_markup is not None else None)
+                             if reply_markup is not None else None),
+            'protect_content': protect_content
         }
 
     files = dict()
@@ -479,7 +500,8 @@ def send_location(token: str,
                   live_period: Optional[int] = None,
                   disable_notification: Optional[bool] = None,
                   reply_to_message_id: Optional[int] = None,
-                  reply_markup: Optional[ReplyMarkup] = None
+                  reply_markup: Optional[ReplyMarkup] = None,
+                  protect_content: Optional[bool] = None
                   ) -> Message:
     """Use this method to send point on the map.
 
@@ -493,7 +515,8 @@ def send_location(token: str,
         'live_period': live_period,
         'disable_notification': disable_notification,
         'reply_to_message_id': reply_to_message_id,
-        'reply_markup': reply_markup.unfold()
+        'reply_markup': reply_markup.unfold(),
+        'protect_content': protect_content
     }
 
     return request(
@@ -580,7 +603,8 @@ def send_venue(token: str,
                foursquare_type: Optional[str] = None,
                disable_notification: Optional[bool] = None,
                reply_to_message_id: Optional[int] = None,
-               reply_markup: Optional[ReplyMarkup] = None
+               reply_markup: Optional[ReplyMarkup] = None,
+               protect_content: Optional[bool] = None
                ) -> Message:
     """Use this method to send information about a venue.
 
@@ -597,7 +621,8 @@ def send_venue(token: str,
         'foursquare_type': foursquare_type,
         'disable_notification': disable_notification,
         'reply_to_message_id': reply_to_message_id,
-        'reply_markup': reply_markup.unfold()
+        'reply_markup': reply_markup.unfold(),
+        'protect_content': protect_content
     }
 
     return request(
@@ -616,7 +641,8 @@ def send_contact(token: str,
                  vcard: Optional[str] = None,
                  disable_notification: Optional[bool] = None,
                  reply_to_message_id: Optional[int] = None,
-                 reply_markup: Optional[ReplyMarkup] = None
+                 reply_markup: Optional[ReplyMarkup] = None,
+                 protect_content: Optional[bool] = None
                  ) -> Message:
     """Use this method to send phone contacts.
 
@@ -630,7 +656,8 @@ def send_contact(token: str,
         'vcard': vcard,
         'disable_notification': disable_notification,
         'reply_to_message_id': reply_to_message_id,
-        'reply_markup': reply_markup.unfold()
+        'reply_markup': reply_markup.unfold(),
+        'protect_content': protect_content
     }
 
     return request(
@@ -656,7 +683,8 @@ def send_poll(token: str,
               is_closed: Optional[bool] = None,
               disable_notification: Optional[bool] = None,
               reply_to_message_id: Optional[int] = None,
-              reply_markup: Optional[ReplyMarkup] = None
+              reply_markup: Optional[ReplyMarkup] = None,
+              protect_content: Optional[bool] = None
               ) -> Message:
     """Use this method to send a native poll.
 
@@ -678,7 +706,8 @@ def send_poll(token: str,
         'is_closed': is_closed,
         'disable_notification': disable_notification,
         'reply_to_message_id': reply_to_message_id,
-        'reply_markup': reply_markup.unfold()
+        'reply_markup': reply_markup.unfold(),
+        'protect_content': protect_content
     }
 
     return request(
@@ -694,7 +723,8 @@ def send_dice(token: str,
               emoji: Optional[str] = None,
               disable_notification: Optional[bool] = None,
               reply_to_message_id: Optional[int] = None,
-              reply_markup: Optional[ReplyMarkup] = None
+              reply_markup: Optional[ReplyMarkup] = None,
+              protect_content: Optional[bool] = None
               ) -> Message:
     """Use this method to send an animated emoji that will display a random value.
 
@@ -706,7 +736,8 @@ def send_dice(token: str,
         'emoji': emoji,
         'disable_notification': disable_notification,
         'reply_to_message_id': reply_to_message_id,
-        'reply_markup': reply_markup.unfold()
+        'reply_markup': reply_markup.unfold(),
+        'protect_content': protect_content
     }
 
     return request(
@@ -1180,7 +1211,9 @@ def answer_callback_query(token: str,
 
 
 def set_my_commands(token: str,
-                    commands: List[BotCommand]
+                    commands: List[BotCommand],
+                    scope: Optional[BotCommandScope] = None,
+                    language_code: Optional[str] = None
                     ) -> bool:
     """Use this method to change the list of the bot's commands.
 
@@ -1190,19 +1223,49 @@ def set_my_commands(token: str,
         token,
         'setMyCommands',
         {
-            'commands': [i.unfold() for i in commands]
+            'commands': [i.unfold() for i in commands],
+            'scope': scope.unfold() if scope else None,
+            'language_code': language_code
         }
     )
 
 
-def get_my_commands(token: str) -> List[BotCommand]:
+def get_my_commands(token: str,
+                    scope: Optional[BotCommandScope] = None,
+                    language_code: Optional[str] = None
+                    ) -> List[BotCommand]:
     """Use this method to get the current list of the bot's commands.
 
     Returns Array of BotCommand on success.
     """
     return request(
         token,
-        'getMyCommands'
+        'getMyCommands',
+        {
+            'scope': scope.unfold() if scope else None,
+            'language_code': language_code
+        }
+    )
+
+
+def delete_my_commands(token: str,
+                       scope: Optional[BotCommandScope] = None,
+                       language_code: Optional[str] = None
+                       ) -> bool:
+    """Use this method to delete the list of the bot's
+    commands for the given scope and user language.
+    After deletion, higher level commands will be shown
+    to affected users.
+    
+    Returns True on success.
+    """
+    return request(
+        token,
+        'deleteMyCommands',
+        {
+            'scope': scope.unfold() if scope else None,
+            'language_code': language_code
+        }
     )
 
 
@@ -1446,7 +1509,8 @@ def send_media_group(token: str,
                      chat_id: Union[int, str],
                      media: List[InputMedia],
                      disable_notification: Optional[bool] = None,
-                     reply_to_message_id: Optional[bool] = None
+                     reply_to_message_id: Optional[bool] = None,
+                     protect_content: Optional[bool] = None
                      ) -> Message:
     """Use this method to send a group of photos or videos as an album.
     On success, an array of the sent Messages is returned
@@ -1457,7 +1521,8 @@ def send_media_group(token: str,
         'chat_id': chat_id,
         'media': [m.unfold() for m in media],
         'disable_notification': disable_notification,
-        'reply_to_message_id': reply_to_message_id
+        'reply_to_message_id': reply_to_message_id,
+        'protect_content': protect_content
     }
 
     files = dict()
